@@ -21,18 +21,18 @@
         #endif
     #endif
 #else
-    #define XEUS_API
+    #define XEUS_API __attribute__((visibility("default")))
 #endif
 
 // Project version
-#define XEUS_VERSION_MAJOR 2
-#define XEUS_VERSION_MINOR 4
+#define XEUS_VERSION_MAJOR 3
+#define XEUS_VERSION_MINOR 1
 #define XEUS_VERSION_PATCH 1
 
 // Binary version
-#define XEUS_BINARY_CURRENT 7
+#define XEUS_BINARY_CURRENT 9
 #define XEUS_BINARY_REVISION 1
-#define XEUS_BINARY_AGE 1
+#define XEUS_BINARY_AGE 0
 
 // Kernel protocol version
 #define XEUS_KERNEL_PROTOCOL_VERSION_MAJOR 5
